pub enum ComboError {
InsufficientlyLongIterator,
IncongruentWeightClasses,
InvalidVehicleId,
InvalidCharacterId,
ImpossibleCharacterId,
ByteHandlerError(ByteHandlerError),
}Expand description
Errors that can occur while constructing or deserializing a Combo.
Variants
InsufficientlyLongIterator
The input iterator did not contain enough bytes to extract a combo.
IncongruentWeightClasses
The character and vehicle belong to different weight classes.
InvalidVehicleId
The vehicle byte did not map to a known Vehicle variant.
InvalidCharacterId
The character byte did not map to a known Character variant.
ImpossibleCharacterId
The character ID corresponds to a character that cannot appear in ghost files.
ByteHandlerError(ByteHandlerError)
A ByteHandler operation failed.