Combo

Struct Combo 

pub struct Combo { /* private fields */ }
Represents a valid character and vehicle combination from a Mario Kart Wii RKG ghost file.

A combo is only valid when the character and vehicle share the same weight_class::WeightClass. Construction via Combo::new enforces this constraint.

Implementations

Source

impl Combo

pub const fn get_transmission(&self) -> Transmission

Source

impl Combo

pub fn new(vehicle: Vehicle, character: Character) -> Result<Self, ComboError>

Creates a new Combo from a vehicle and character.

Errors

Returns ComboError::IncongruentWeightClasses if the character and vehicle do not share the same WeightClass.

pub const fn character(&self) -> Character

Returns the character used in the run.

pub const fn vehicle(&self) -> Vehicle

Returns the vehicle used in the run.