pub enum DateError {
YearInvalid,
MonthInvalid,
DayInvalid,
ByteHandlerError(ByteHandlerError),
}Expand description
Errors that can occur while constructing a Date.
Variants
YearInvalid
The year is outside the valid range (2000–2035).
MonthInvalid
The month is outside the valid range (1–12).
DayInvalid
The day is zero, or exceeds the maximum number of days for the given month and year.
ByteHandlerError(ByteHandlerError)
A ByteHandler operation failed.