Module dpad_input

Module dpad_input 

Structs

DPadInput
A single run-length encoded D-pad input entry from a Mario Kart Wii ghost file.

Enums

DPadButton
A D-pad button state for a single input entry in a Mario Kart Wii ghost file.
DPadButtonError
Errors that can occur while parsing a DPadButton.
DPadInputError
Errors that can occur while parsing a DPadInput.

Functions

parse_dpad_button
Extracts a DPadButton from the upper nibble of a packed input byte.