Module face_input

Module face_input 

Structs

FaceInput
A single encoded face-button input entry from a Mario Kart Wii ghost file.

Enums

FaceButton
A face button that can be active during a single input entry.
FaceButtonError
Errors that can occur while parsing a FaceButton combination.
FaceInputError
Errors that can occur while parsing a FaceInput.

Functions

parse_face_buttons
Parses all active FaceButtons from a packed face-button byte.