pub enum WeightClass {
Small,
Medium,
Large,
}Expand description
The weight class of a character or vehicle in Mario Kart Wii.
A valid Combo requires the character and vehicle to share the same weight class.
Variants