pub struct Combo { /* private fields */ }Expand description
Represents a valid character and vehicle combination from a Mario Kart Wii RKG ghost file.
A combo is only valid when the character and vehicle share the same weight_class::WeightClass.
Construction via Combo::new enforces this constraint.
Implementations
Sourceimpl Combo
impl Combo
pub const fn get_transmission(&self) -> Transmission
Sourceimpl Combo
impl Combo
Sourcepub fn new(vehicle: Vehicle, character: Character) -> Result<Self, ComboError>
pub fn new(vehicle: Vehicle, character: Character) -> Result<Self, ComboError>
Creates a new Combo from a vehicle and character.
Errors
Returns ComboError::IncongruentWeightClasses if the character and vehicle
do not share the same WeightClass.