pub enum HeaderError {
Show 16 variants
NotRKGD,
NotCorrectSize,
FriendNumberOutOfRange,
LapSplitIndexError,
InGameTimeError(InGameTimeError),
SlotIdError(SlotIdError),
ComboError(ComboError),
DateError(DateError),
ControllerError(ControllerError),
TransmissionModError(TransmissionModError),
GhostTypeError(GhostTypeError),
MiiError(MiiError),
IoError(Error),
CountryError(CountryError),
SubregionError(SubregionError),
ByteHandlerError(ByteHandlerError),
}Expand description
Errors that can occur while parsing or modifying a Header.
Variants
NotRKGD
The file does not begin with the RKGD magic bytes.
NotCorrectSize
The input slice is not exactly 0x88 bytes long.
FriendNumberOutOfRange
A friend ghost number was specified outside the valid range of 1–30.
LapSplitIndexError
A lap split idx was out of bounds for the recorded lap count.
InGameTimeError(InGameTimeError)
A finish or lap time field could not be parsed.
SlotIdError(SlotIdError)
The slot ID field could not be parsed.
ComboError(ComboError)
The character/vehicle combo field could not be parsed.
DateError(DateError)
The date field could not be parsed.
ControllerError(ControllerError)
The controller field could not be parsed.
TransmissionModError(TransmissionModError)
The transmission mod field could not be parsed.
GhostTypeError(GhostTypeError)
The ghost type field could not be parsed.
MiiError(MiiError)
The embedded Mii data could not be parsed.
IoError(Error)
A file I/O operation failed.
CountryError(CountryError)
The country code could not be parsed.
SubregionError(SubregionError)
The subregion code could not be parsed.
ByteHandlerError(ByteHandlerError)
A ByteHandler operation failed.