Structs
- DPad
Input - A single run-length encoded D-pad input entry from a Mario Kart Wii ghost file.
Enums
- DPad
Button - A D-pad button state for a single input entry in a Mario Kart Wii ghost file.
- DPad
Button Error - Errors that can occur while parsing a
DPadButton. - DPad
Input Error - Errors that can occur while parsing a
DPadInput.
Functions
- parse_
dpad_ button - Extracts a
DPadButtonfrom the upper nibble of a packed input byte.