Structs
- Face
Input - A single encoded face-button input entry from a Mario Kart Wii ghost file.
Enums
- Face
Button - A face button that can be active during a single input entry.
- Face
Button Error - Errors that can occur while parsing a
FaceButtoncombination. - Face
Input Error - Errors that can occur while parsing a
FaceInput.
Functions
- parse_
face_ buttons - Parses all active
FaceButtons from a packed face-button byte.